@@ -1,7 +1,7 @@
 package App::rimetadb;
 
-our $DATE = '2015-12-01'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2016-01-03'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -131,15 +131,19 @@ _
     },
 );
 
+our %args_query_detail = (
+    detail => {
+        schema => 'bool',
+        cmdline_aliases => {l=>{}},
+    },
+);
+
 our %args_query = (
     query => {
         schema => 'str*',
         pos => 0,
     },
-    detail => {
-        schema => 'bool',
-        cmdline_aliases => {l=>{}},
-    },
+    %args_query_detail,
 );
 
 sub _is_excluded {
@@ -585,6 +589,60 @@ sub stats {
     [200, "OK", \%stats];
 }
 
+$SPEC{arguments} = {
+    v => 1.1,
+    summary => 'List function arguments',
+    args => {
+        %args_common,
+        #%args_query,
+        %args_query_detail,
+    },
+};
+sub arguments {
+    my %args = @_;
+
+    my ($res, $dbh) = _connect_db(\%args);
+    return $res unless $res->[0] == 200;
+
+    #my $q  = $args{query};
+
+    my @rows;
+    #my @columns = qw(package name summary dist mtime extra);
+    my @wheres;
+    my @binds;
+
+    #if (length $q) {
+    #    push @wheres, "(package LIKE ? OR name LIKE ? OR dist LIKE ? OR extra LIKE ?)";
+    #    push @binds, $q, $q, $q, $q;
+    #}
+
+    my $sth = $dbh->prepare(
+        "SELECT package,name,metadata FROM function".
+            (@wheres ? " WHERE ".join(" AND ", @wheres) : "")
+    );
+    $sth->execute(@binds);
+
+    my %num_occurences;
+    while (my $row = $sth->fetchrow_hashref) {
+        my $meta = _json->decode($row->{metadata});
+        my $args = $meta->{args} // {};
+        for (keys %$args) {
+            $num_occurences{$_}++;
+        }
+    }
+
+    for (sort keys %num_occurences) {
+        push @rows, {name=>$_, num_occurences=>$num_occurences{$_}};
+    }
+
+    unless ($args{detail}) {
+        @rows = map {$_->{name}} @rows;
+    }
+
+    my @columns = qw(name num_occurences);
+    [200, "OK", \@rows, {'table.fields'=>\@columns}];
+}
+
 1;
 # ABSTRACT: Manage a Rinci metadata database
 
@@ -600,7 +658,7 @@ App::rimetadb - Manage a Rinci metadata database
 
 =head1 VERSION
 
-This document describes version 0.14 of App::rimetadb (from Perl distribution App-rimetadb), released on 2015-12-01.
+This document describes version 0.15 of App::rimetadb (from Perl distribution App-rimetadb), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -613,6 +671,49 @@ L<Rinci>
 =head1 FUNCTIONS
 
 
+=head2 arguments(%args) -> [status, msg, result, meta]
+
+List function arguments.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<detail> => I<bool>
+
+=item * B<dsn> => I<str>
+
+DBI connection DSN.
+
+If not specified, will default to C<dbd:SQLite:$HOME/rimeta.db> where C<$HOME> is
+user's home directory.
+
+Note: has been tested with MySQL and SQLite only.
+
+=item * B<password> => I<str>
+
+DBI connection password.
+
+=item * B<user> => I<str>
+
+DBI connection user.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 delete(%args) -> [status, msg, result, meta]
 
 Delete a package or function metadata.
@@ -934,7 +1035,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-rimeta
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-rimetadb>.
+Source repository is at L<https://github.com/perlancar/perl-App-UpdateRinciMetadataDb>.
 
 =head1 BUGS
 
@@ -950,7 +1051,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
